@@ -60,9 +60,7 @@ mod testes {
         assert_eq!(
             Box::new(command.clone()),
             denormalized,
-            "{:?}, {:?}",
-            command,
-            denormalized
+            "{command:?}, {denormalized:?}",
         );
     }
 }
